@@ -1,10 +1,16 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 
 # Author: Samuele Pilleri
 # Date: August 17th, 2015
 
+import bz2
+import sqlite3
 import sys
+import tempfile
+import time
 import urllib2
+import zlib
+
 from lxml import html
 
 #
@@ -122,14 +128,14 @@ repos = {
     ],
 
     "CoreOS" : [
-        {
-            "root" : "http://alpha.release.core-os.net/",
-            "discovery_pattern": "/html/body//a[regex:test(@href, 'amd64-usr')]/@href",
-            "subdirs" : [
-                ""
-            ],
-            "page_pattern" : "/html/body//a[regex:test(@href, '^[5-9][0-9][0-9]|current|[1][0-9]{3}')]/@href"
-        },
+        # {
+        #     "root" : "http://alpha.release.core-os.net/",
+        #     "discovery_pattern": "/html/body//a[regex:test(@href, 'amd64-usr')]/@href",
+        #     "subdirs" : [
+        #         ""
+        #     ],
+        #     "page_pattern" : "/html/body//a[regex:test(@href, '^[5-9][0-9][0-9]|current|[1][0-9]{3}')]/@href"
+        # },
 
         {
             "root" : "http://beta.release.core-os.net/",
@@ -156,25 +162,93 @@ repos = {
             "discovery_pattern": "/html/body/pre/a[@href = 'linux/']/@href",
             "subdirs": [""],
             "page_pattern": "/html/body//a[regex:test(@href, '^linux-(image|headers)-[3-9]\.[0-9]+\.[0-9]+.*amd64.deb$')]/@href",
-            "exclude_patterns": ["-rt", "dbg", "trunk", "all", "exp", "unsigned"]
+            "exclude_patterns": ["-rt", "dbg", "trunk", "all", "exp", "unsigned", "cloud-amd64"]
         },
         {
             "root": "http://security.debian.org/pool/updates/main/l/",
             "discovery_pattern": "/html/body/table//tr/td/a[@href = 'linux/']/@href",
             "subdirs": [""],
             "page_pattern": "/html/body//a[regex:test(@href, '^linux-(image|headers)-[3-9]\.[0-9]+\.[0-9]+.*amd64.deb$')]/@href",
-            "exclude_patterns": ["-rt", "dbg", "trunk", "all", "exp", "unsigned"]
+            "exclude_patterns": ["-rt", "dbg", "trunk", "all", "exp", "unsigned", "cloud-amd64"]
         },
         {
             "root": "http://mirrors.kernel.org/debian/pool/main/l/",
             "discovery_pattern": "/html/body/pre/a[@href = 'linux-tools/']/@href",
             "subdirs": [""],
             "page_pattern": "/html/body//a[regex:test(@href, '^linux-kbuild-.*amd64.deb$')]/@href",
-            "exclude_patterns": ["-rt", "dbg", "trunk", "all", "exp", "unsigned"]
+            "exclude_patterns": ["-rt", "dbg", "trunk", "all", "exp", "unsigned", "cloud-amd64"]
         }
     ]
 }
 
+# Build static list, 2017.09 is last Amazon Linux AMI release https://aws.amazon.com/amazon-linux-2/faqs/
+amazon_linux_builder = [('latest', 'updates'), ('latest', 'main'), ('2017.03', 'updates'), ('2017.03', 'main')]
+amazon_repos = []
+for repo_release, release_type in amazon_linux_builder:
+    amazon_repos.append({
+        "root": "http://repo.us-east-1.amazonaws.com/" + repo_release + "/" + release_type + "/mirror.list",
+        "discovery_pattern": "SELECT * FROM packages WHERE name LIKE 'kernel%'",
+        "subdirs": [""],
+        "page_pattern": "",
+        "exclude_patterns": ["doc", "tools", "headers"]
+    })
+repos['AmazonLinux'] = amazon_repos
+
+prev_months = 24
+now = time.localtime()
+check_months = [time.localtime(time.mktime((now.tm_year, now.tm_mon - n, 1, 0, 0, 0, 0, 0, 0)))[:2] for n in range(prev_months)]
+amazon_linux2 = []
+for year, month in check_months[:-1]:
+    amazon_linux2.append({
+        "root": "http://amazonlinux.us-east-1.amazonaws.com/" + str(year) + "." + str(month).zfill(2) + "/core/latest/x86_64/mirror.list",
+        "discovery_pattern": "SELECT * FROM packages WHERE name LIKE 'kernel%'",
+        "subdirs": [""],
+        "page_pattern": "",
+        "exclude_patterns": ["doc", "tools", "headers"]
+        })
+
+repos['AmazonLinux2'] = amazon_linux2
+
+def exclude_patterns(repo, packages, base_url, urls):
+    for rpm in packages:
+        if "exclude_patterns" in repo and any(x in rpm for x in repo["exclude_patterns"]):
+            continue
+        else:
+            urls.add(base_url + str(urllib2.unquote(rpm)))
+
+def process_al_distro(al_distro_name, current_repo):
+    get_url = urllib2.urlopen(current_repo["root"]).readline()
+    if get_url:
+        if al_distro_name == "AmazonLinux":
+            base_mirror_url = get_url.replace('$basearch','x86_64').replace('\n','') + '/'
+            db_path = "repodata/primary.sqlite.bz2"
+        elif al_distro_name == "AmazonLinux2":
+            base_mirror_url = get_url.replace('\n','') + '/'
+            db_path = "repodata/primary.sqlite.gz"
+        
+        response = urllib2.urlopen(base_mirror_url + db_path)
+
+        if al_distro_name == "AmazonLinux":
+            decompressed_data = bz2.decompress(response.read())
+        elif al_distro_name == "AmazonLinux2":
+            decompressed_data = zlib.decompress(response.read(), 16+zlib.MAX_WBITS)
+
+        db_file = tempfile.NamedTemporaryFile()
+        db_file.write(decompressed_data)
+        conn = sqlite3.connect(db_file.name)
+        conn.row_factory = sqlite3.Row
+        c = conn.cursor()
+        al_rpms = [r["location_href"] for r in c.execute(current_repo["discovery_pattern"])]
+        exclude_patterns(current_repo, al_rpms, base_mirror_url, urls)
+        conn.close()
+        db_file.close()
+
+        return True
+
+    else:
+        return False
+
+
 #
 # In our design you are not supposed to modify the code. The whole script is
 # created so that you just have to add entry to the `repos` array and new
@@ -188,33 +262,48 @@ if len(sys.argv) < 2 or not sys.argv[1] in repos:
     sys.stderr.write("Usage: " + sys.argv[0] + " <distro>\n")
     sys.exit(1)
 
+distro = sys.argv[1]
+
 #
 # Navigate the `repos` tree and look for packages we need that match the
 # patterns given. Save the result in `packages`.
 #
-for repo in repos[sys.argv[1]]:
-    try:
-        root = urllib2.urlopen(repo["root"],timeout=URL_TIMEOUT).read()
-    except:
-        continue
-    versions = html.fromstring(root).xpath(repo["discovery_pattern"], namespaces = {"regex": "http://exslt.org/regular-expressions"})
-    for version in versions:
-        for subdir in repo["subdirs"]:
-            # The try - except block is used because 404 errors and similar
-            # might happen (and actually happen because not all repos have
-            # packages we need)
-            try:
-                source = repo["root"] + version + subdir
-                page = urllib2.urlopen(source,timeout=URL_TIMEOUT).read()
-                rpms = html.fromstring(page).xpath(repo["page_pattern"], namespaces = {"regex": "http://exslt.org/regular-expressions"})
 
-                for rpm in rpms:
-                    if "exclude_patterns" in repo and any(x in rpm for x in repo["exclude_patterns"]):
-                        continue
-                    else:
-                        urls.add(source + str(urllib2.unquote(rpm)))
-            except:
-                continue
+al2_repo_count = 0
+
+for repo in repos[distro]:
+    if distro == 'AmazonLinux':
+        try:
+            process_al_distro(distro, repo)
+        except:
+            continue
+    elif distro == 'AmazonLinux2':
+        try:
+            # Brute force finding the repositories and only grab the most recent two, then skip the rest.
+            if al2_repo_count < 2:
+                if process_al_distro(distro, repo):
+                    al2_repo_count += 1
+        except:
+            continue
+    else:
+        try:
+            root = urllib2.urlopen(repo["root"],timeout=URL_TIMEOUT).read()
+        except:
+            continue
+
+        versions = html.fromstring(root).xpath(repo["discovery_pattern"], namespaces = {"regex": "http://exslt.org/regular-expressions"})
+        for version in versions:
+            for subdir in repo["subdirs"]:
+                # The try - except block is used because 404 errors and similar
+                # might happen (and actually happen because not all repos have
+                # packages we need)
+                try:
+                    source = repo["root"] + version + subdir
+                    page = urllib2.urlopen(source,timeout=URL_TIMEOUT).read()
+                    rpms = html.fromstring(page).xpath(repo["page_pattern"], namespaces = {"regex": "http://exslt.org/regular-expressions"})
+                    exclude_patterns(repo, rpms, source, urls)
+                except:
+                    continue
 
 #
 # Print URLs to stdout
