@@ -23,3 +23,8 @@ const struct ppm_param_info ptrace_dynamic_param[PPM_PTRACE_IDX_MAX] = {
 	{{0}, PT_UINT64, PF_HEX},
 	{{0}, PT_SIGTYPE, PF_DEC},
 };
+
+const struct ppm_param_info bpf_dynamic_param[PPM_BPF_IDX_MAX] = {
+	[PPM_BPF_IDX_FD] = {{0}, PT_FD, PF_DEC},
+	[PPM_BPF_IDX_RES] = {{0}, PT_ERRNO, PF_DEC},
+};
