@@ -30,9 +30,16 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 #include <sys/time.h>
 #endif // _WIN32
 
+#ifdef CYGWING_AGENT
+#define DRAGENT_WIN_HAL_C_ONLY
+#include <dragent_win_hal_public.h>
+#endif
+
 #include "scap.h"
 #ifdef HAS_CAPTURE
+#ifndef CYGWING_AGENT
 #include "../../driver/driver_config.h"
+#endif // CYGWING_AGENT
 #endif // HAS_CAPTURE
 #include "../../driver/ppm_ringbuffer.h"
 #include "scap_savefile.h"
@@ -46,13 +53,14 @@ char* scap_getlasterr(scap_t* handle)
 	return handle->m_lasterr;
 }
 
-#if !defined(HAS_CAPTURE)
-scap_t* scap_open_live_int(char *error,
-						   proc_entry_callback proc_callback,
-						   void* proc_callback_context,
-						   bool import_users)
+#if !defined(HAS_CAPTURE) || defined(CYGWING_AGENT)
+scap_t* scap_open_live_int(char *error, int32_t *rc,
+			   proc_entry_callback proc_callback,
+			   void* proc_callback_context,
+			   bool import_users)
 {
 	snprintf(error, SCAP_LASTERR_SIZE, "live capture not supported on %s", PLATFORM_NAME);
+	*rc = SCAP_NOT_SUPPORTED;
 	return NULL;
 }
 #else
@@ -75,17 +83,16 @@ static uint32_t get_max_consumers()
 	return 0;
 }
 
-scap_t* scap_open_live_int(char *error,
-						   proc_entry_callback proc_callback,
-						   void* proc_callback_context,
-						   bool import_users)
+scap_t* scap_open_live_int(char *error, int32_t *rc,
+			   proc_entry_callback proc_callback,
+			   void* proc_callback_context,
+			   bool import_users)
 {
 	uint32_t j;
 	char filename[SCAP_MAX_PATH_SIZE];
 	scap_t* handle = NULL;
 	int len;
 	uint32_t ndevs;
-	uint32_t res;
 	uint32_t max_devs;
 	uint32_t all_scanned_devs;
 
@@ -96,6 +103,7 @@ scap_t* scap_open_live_int(char *error,
 	if(!handle)
 	{
 		snprintf(error, SCAP_LASTERR_SIZE, "error allocating the scap_t structure");
+		*rc = SCAP_FAILURE;
 		return NULL;
 	}
 
@@ -121,6 +129,7 @@ scap_t* scap_open_live_int(char *error,
 	{
 		scap_close(handle);
 		snprintf(error, SCAP_LASTERR_SIZE, "error allocating the device handles");
+		*rc = SCAP_FAILURE;
 		return NULL;
 	}
 
@@ -146,10 +155,14 @@ scap_t* scap_open_live_int(char *error,
 	handle->m_machine_info.reserved4 = 0;
 	handle->m_driver_procinfo = NULL;
 	handle->m_fd_lookup_limit = 0;
+#ifdef CYGWING_AGENT
+	handle->m_whh = NULL;
+#endif
+
 	//
 	// Create the interface list
 	//
-	if(scap_create_iflist(handle) != SCAP_SUCCESS)
+	if((*rc = scap_create_iflist(handle)) != SCAP_SUCCESS)
 	{
 		scap_close(handle);
 		snprintf(error, SCAP_LASTERR_SIZE, "error creating the interface list");
@@ -161,7 +174,7 @@ scap_t* scap_open_live_int(char *error,
 	//
 	if(import_users)
 	{
-		if(scap_create_userlist(handle) != SCAP_SUCCESS)
+		if((*rc = scap_create_userlist(handle)) != SCAP_SUCCESS)
 		{
 			scap_close(handle);
 			snprintf(error, SCAP_LASTERR_SIZE, "error creating the interface list");
@@ -211,6 +224,7 @@ scap_t* scap_open_live_int(char *error,
 			}
 
 			scap_close(handle);
+			*rc = SCAP_FAILURE;
 			return NULL;
 		}
 
@@ -218,6 +232,7 @@ scap_t* scap_open_live_int(char *error,
 		if (fcntl(handle->m_devs[j].m_fd, F_SETFD, FD_CLOEXEC) == -1) {
 			snprintf(error, SCAP_LASTERR_SIZE, "Can not set close-on-exec flag for fd for device %s (%s)", filename, strerror(errno));
 			scap_close(handle);
+			*rc = SCAP_FAILURE;
 			return NULL;
 		}
 
@@ -239,6 +254,7 @@ scap_t* scap_open_live_int(char *error,
 			scap_close(handle);
 
 			snprintf(error, SCAP_LASTERR_SIZE, "error mapping the ring buffer for device %s", filename);
+			*rc = SCAP_FAILURE;
 			return NULL;
 		}
 
@@ -261,6 +277,7 @@ scap_t* scap_open_live_int(char *error,
 			scap_close(handle);
 
 			snprintf(error, SCAP_LASTERR_SIZE, "error mapping the ring buffer info for device %s", filename);
+			*rc = SCAP_FAILURE;
 			return NULL;
 		}
 
@@ -279,7 +296,7 @@ scap_t* scap_open_live_int(char *error,
 	//
 	error[0] = '\0';
 	snprintf(filename, sizeof(filename), "%s/proc", scap_get_host_root());
-	if((res = scap_proc_scan_proc_dir(handle, filename, -1, -1, NULL, error, true)) != SCAP_SUCCESS)
+	if((*rc = scap_proc_scan_proc_dir(handle, filename, -1, -1, NULL, error, true)) != SCAP_SUCCESS)
 	{
 		scap_close(handle);
 		snprintf(error, SCAP_LASTERR_SIZE, "error creating the process list. Make sure you have root credentials.");
@@ -296,11 +313,12 @@ scap_t* scap_open_live_int(char *error,
 #endif // HAS_CAPTURE
 
 scap_t* scap_open_offline_int(gzFile gzfile,
-							  char *error,
-							  proc_entry_callback proc_callback,
-							  void* proc_callback_context,
-							  bool import_users,
-							  uint64_t start_offset)
+			      char *error,
+			      int32_t *rc,
+			      proc_entry_callback proc_callback,
+			      void* proc_callback_context,
+			      bool import_users,
+			      uint64_t start_offset)
 {
 	scap_t* handle = NULL;
 
@@ -311,6 +329,7 @@ scap_t* scap_open_offline_int(gzFile gzfile,
 	if(!handle)
 	{
 		snprintf(error, SCAP_LASTERR_SIZE, "error allocating the scap_t structure");
+		*rc = SCAP_FAILURE;
 		return NULL;
 	}
 
@@ -332,12 +351,16 @@ scap_t* scap_open_offline_int(gzFile gzfile,
 	handle->m_driver_procinfo = NULL;
 	handle->refresh_proc_table_when_saving = true;
 	handle->m_fd_lookup_limit = 0;
+#ifdef CYGWING_AGENT
+	handle->m_whh = NULL;
+#endif
 
 	handle->m_file_evt_buf = (char*)malloc(FILE_READ_BUF_SIZE);
 	if(!handle->m_file_evt_buf)
 	{
 		snprintf(error, SCAP_LASTERR_SIZE, "error allocating the read buffer");
 		scap_close(handle);
+		*rc = SCAP_FAILURE;
 		return NULL;
 	}
 
@@ -354,7 +377,7 @@ scap_t* scap_open_offline_int(gzFile gzfile,
 	//
 	// Validate the file and load the non-event blocks
 	//
-	if(scap_read_init(handle, handle->m_file) != SCAP_SUCCESS)
+	if((*rc = scap_read_init(handle, handle->m_file)) != SCAP_SUCCESS)
 	{
 		snprintf(error, SCAP_LASTERR_SIZE, "Could not initialize reader: %s", scap_getlasterr(handle));
 		scap_close(handle);
@@ -383,42 +406,45 @@ scap_t* scap_open_offline_int(gzFile gzfile,
 	return handle;
 }
 
-scap_t* scap_open_offline(const char* fname, char *error)
+scap_t* scap_open_offline(const char* fname, char *error, int32_t* rc)
 {
 	gzFile gzfile = gzopen(fname, "rb");
 	if(gzfile == NULL)
 	{
 		snprintf(error, SCAP_LASTERR_SIZE, "can't open file %s", fname);
+		*rc = SCAP_FAILURE;
 		return NULL;
 	}
 
-	return scap_open_offline_int(gzfile, error, NULL, NULL, true, 0);
+	return scap_open_offline_int(gzfile, error, rc, NULL, NULL, true, 0);
 }
 
-scap_t* scap_open_offline_fd(int fd, char *error)
+scap_t* scap_open_offline_fd(int fd, char *error, int32_t *rc)
 {
 	gzFile gzfile = gzdopen(fd, "rb");
 	if(gzfile == NULL)
 	{
 		snprintf(error, SCAP_LASTERR_SIZE, "can't open fd %d", fd);
+		*rc = SCAP_FAILURE;
 		return NULL;
 	}
 
-	return scap_open_offline_int(gzfile, error, NULL, NULL, true, 0);
+	return scap_open_offline_int(gzfile, error, rc, NULL, NULL, true, 0);
 }
 
-scap_t* scap_open_live(char *error)
+scap_t* scap_open_live(char *error, int32_t *rc)
 {
-	return scap_open_live_int(error, NULL, NULL, true);
+	return scap_open_live_int(error, rc, NULL, NULL, true);
 }
 
-scap_t* scap_open_nodriver_int(char *error,
-						   proc_entry_callback proc_callback,
-						   void* proc_callback_context,
-						   bool import_users)
+scap_t* scap_open_nodriver_int(char *error, int32_t *rc,
+			       proc_entry_callback proc_callback,
+			       void* proc_callback_context,
+			       bool import_users)
 {
 #if !defined(HAS_CAPTURE)
 	snprintf(error, SCAP_LASTERR_SIZE, "live capture not supported on %s", PLATFORM_NAME);
+	*rc = SCAP_NOT_SUPPORTED;
 	return NULL;
 #else
 	char filename[SCAP_MAX_PATH_SIZE];
@@ -431,6 +457,7 @@ scap_t* scap_open_nodriver_int(char *error,
 	if(!handle)
 	{
 		snprintf(error, SCAP_LASTERR_SIZE, "error allocating the scap_t structure");
+		*rc = SCAP_FAILURE;
 		return NULL;
 	}
 
@@ -455,10 +482,23 @@ scap_t* scap_open_nodriver_int(char *error,
 	handle->m_driver_procinfo = NULL;
 	handle->m_fd_lookup_limit = SCAP_NODRIVER_MAX_FD_LOOKUP; // fd lookup is limited here because is very expensive
 
+	//
+	// If this is part of the windows agent, open the windows HAL
+	//
+#ifdef CYGWING_AGENT
+	handle->m_whh = wh_open(error);
+	if(handle->m_whh == NULL)
+	{
+		scap_close(handle);
+		*rc = SCAP_FAILURE;
+		return NULL;
+	}
+#endif
+
 	//
 	// Create the interface list
 	//
-	if(scap_create_iflist(handle) != SCAP_SUCCESS)
+	if((*rc = scap_create_iflist(handle)) != SCAP_SUCCESS)
 	{
 		scap_close(handle);
 		snprintf(error, SCAP_LASTERR_SIZE, "error creating the interface list");
@@ -470,7 +510,7 @@ scap_t* scap_open_nodriver_int(char *error,
 	//
 	if(import_users)
 	{
-		if(scap_create_userlist(handle) != SCAP_SUCCESS)
+		if((*rc = scap_create_userlist(handle)) != SCAP_SUCCESS)
 		{
 			scap_close(handle);
 			snprintf(error, SCAP_LASTERR_SIZE, "error creating the interface list");
@@ -495,7 +535,7 @@ scap_t* scap_open_nodriver_int(char *error,
 	//
 	error[0] = '\0';
 	snprintf(filename, sizeof(filename), "%s/proc", scap_get_host_root());
-	if(scap_proc_scan_proc_dir(handle, filename, -1, -1, NULL, error, true) != SCAP_SUCCESS)
+	if((*rc = scap_proc_scan_proc_dir(handle, filename, -1, -1, NULL, error, true)) != SCAP_SUCCESS)
 	{
 		scap_close(handle);
 		snprintf(error, SCAP_LASTERR_SIZE, "error creating the process list. Make sure you have root credentials.");
@@ -506,7 +546,7 @@ scap_t* scap_open_nodriver_int(char *error,
 #endif // HAS_CAPTURE
 }
 
-scap_t* scap_open(scap_open_args args, char *error)
+scap_t* scap_open(scap_open_args args, char *error, int32_t *rc)
 {
 	switch(args.mode)
 	{
@@ -533,22 +573,31 @@ scap_t* scap_open(scap_open_args args, char *error)
 			{
 				snprintf(error, SCAP_LASTERR_SIZE, "can't open file %s", args.fname);
 			}
+			*rc = SCAP_FAILURE;
 			return NULL;
 		}
 
-		return scap_open_offline_int(gzfile, error,
-									 args.proc_callback, args.proc_callback_context,
-									 args.import_users, args.start_offset);
+		return scap_open_offline_int(gzfile, error, rc,
+					     args.proc_callback, args.proc_callback_context,
+					     args.import_users, args.start_offset);
 	}
 	case SCAP_MODE_LIVE:
-		return scap_open_live_int(error, args.proc_callback,
-								  args.proc_callback_context,
-								  args.import_users);
+#ifndef CYGWING_AGENT
+		return scap_open_live_int(error, rc, args.proc_callback,
+					  args.proc_callback_context,
+					  args.import_users);
+#else
+		snprintf(error,	SCAP_LASTERR_SIZE, "scap_open: live mode currently not supported on windows. Use nodriver mode instead.");
+		*rc = SCAP_NOT_SUPPORTED;
+		return NULL;
+#endif								  
 	case SCAP_MODE_NODRIVER:
-		return scap_open_nodriver_int(error, args.proc_callback,
-									  args.proc_callback_context,
-									  args.import_users);
+		return scap_open_nodriver_int(error, rc, args.proc_callback,
+					      args.proc_callback_context,
+					      args.import_users);
 	default:
+		snprintf(error, SCAP_LASTERR_SIZE, "incorrect mode %d", args.mode);
+		*rc = SCAP_FAILURE;
 		return NULL;
 	}
 }
@@ -589,6 +638,13 @@ void scap_close(scap_t* handle)
 #endif // HAS_CAPTURE
 	}
 
+#ifdef CYGWING_AGENT
+	if(handle->m_whh != NULL)
+	{
+		wh_close(handle->m_whh);
+	}
+#endif
+
 	if(handle->m_file_evt_buf)
 	{
 		free(handle->m_file_evt_buf);
@@ -970,7 +1026,7 @@ int32_t scap_get_stats(scap_t* handle, OUT scap_stats* stats)
 //
 int32_t scap_stop_capture(scap_t* handle)
 {
-#if !defined(HAS_CAPTURE)
+#if !defined(HAS_CAPTURE) || defined(CYGWING_AGENT)
 	snprintf(handle->m_lasterr, SCAP_LASTERR_SIZE, "live capture not supported on %s", PLATFORM_NAME);
 	return SCAP_FAILURE;
 #else
@@ -1008,7 +1064,7 @@ int32_t scap_stop_capture(scap_t* handle)
 //
 int32_t scap_start_capture(scap_t* handle)
 {
-#if !defined(HAS_CAPTURE)
+#if !defined(HAS_CAPTURE) || defined(CYGWING_AGENT)
 	snprintf(handle->m_lasterr, SCAP_LASTERR_SIZE, "live capture not supported on %s", PLATFORM_NAME);
 	return SCAP_FAILURE;
 #else
@@ -1041,7 +1097,7 @@ int32_t scap_start_capture(scap_t* handle)
 #endif // HAS_CAPTURE
 }
 
-#if defined(HAS_CAPTURE)
+#if defined(HAS_CAPTURE) && !defined(CYGWING_AGENT)
 static int32_t scap_set_dropping_mode(scap_t* handle, int request, uint32_t sampling_ratio)
 {
 	//
@@ -1079,7 +1135,7 @@ static int32_t scap_set_dropping_mode(scap_t* handle, int request, uint32_t samp
 }
 #endif
 
-#if defined(HAS_CAPTURE)
+#if defined(HAS_CAPTURE) && ! defined(CYGWING_AGENT)
 int32_t scap_enable_tracers_capture(scap_t* handle)
 {
 	//
@@ -1106,7 +1162,7 @@ int32_t scap_enable_tracers_capture(scap_t* handle)
 }
 #endif
 
-#if defined(HAS_CAPTURE)
+#if defined(HAS_CAPTURE) && ! defined(CYGWING_AGENT)
 int32_t scap_enable_page_faults(scap_t *handle)
 {
 	if(handle->m_mode != SCAP_MODE_LIVE)
@@ -1132,7 +1188,7 @@ int32_t scap_enable_page_faults(scap_t *handle)
 
 int32_t scap_stop_dropping_mode(scap_t* handle)
 {
-#if !defined(HAS_CAPTURE)
+#if !defined(HAS_CAPTURE) || defined(CYGWING_AGENT)
 	snprintf(handle->m_lasterr, SCAP_LASTERR_SIZE, "live capture not supported on %s", PLATFORM_NAME);
 	return SCAP_FAILURE;
 #else
@@ -1142,7 +1198,7 @@ int32_t scap_stop_dropping_mode(scap_t* handle)
 
 int32_t scap_start_dropping_mode(scap_t* handle, uint32_t sampling_ratio)
 {
-#if !defined(HAS_CAPTURE)
+#if !defined(HAS_CAPTURE) || defined(CYGWING_AGENT)
 	snprintf(handle->m_lasterr, SCAP_LASTERR_SIZE, "live capture not supported on %s", PLATFORM_NAME);
 	return SCAP_FAILURE;
 #else
@@ -1195,7 +1251,7 @@ int32_t scap_set_snaplen(scap_t* handle, uint32_t snaplen)
 		return SCAP_FAILURE;
 	}
 
-#if !defined(HAS_CAPTURE)
+#if !defined(HAS_CAPTURE) || defined(CYGWING_AGENT)
 	snprintf(handle->m_lasterr, SCAP_LASTERR_SIZE, "live capture not supported on %s", PLATFORM_NAME);
 	return SCAP_FAILURE;
 #else
@@ -1242,6 +1298,7 @@ int64_t scap_get_readfile_offset(scap_t* handle)
 	return gzoffset(handle->m_file);
 }
 
+#ifndef CYGWING_AGENT
 static int32_t scap_handle_eventmask(scap_t* handle, uint32_t op, uint32_t event_id)
 {
 	//
@@ -1300,11 +1357,12 @@ static int32_t scap_handle_eventmask(scap_t* handle, uint32_t op, uint32_t event
 	}
 
 	return SCAP_SUCCESS;
-#endif
+#endif // HAS_CAPTURE
 }
+#endif // CYGWING_AGENT
 
 int32_t scap_clear_eventmask(scap_t* handle) {
-#if !defined(HAS_CAPTURE)
+#if !defined(HAS_CAPTURE) || defined(CYGWING_AGENT)
 	snprintf(handle->m_lasterr, SCAP_LASTERR_SIZE, "eventmask not supported on %s", PLATFORM_NAME);
 	return SCAP_FAILURE;
 #else
@@ -1313,7 +1371,7 @@ int32_t scap_clear_eventmask(scap_t* handle) {
 }
 
 int32_t scap_set_eventmask(scap_t* handle, uint32_t event_id) {
-#if !defined(HAS_CAPTURE)
+#if !defined(HAS_CAPTURE) || defined(CYGWING_AGENT)
 	snprintf(handle->m_lasterr, SCAP_LASTERR_SIZE, "eventmask not supported on %s", PLATFORM_NAME);
 	return SCAP_FAILURE;
 #else
@@ -1322,7 +1380,7 @@ int32_t scap_set_eventmask(scap_t* handle, uint32_t event_id) {
 }
 
 int32_t scap_unset_eventmask(scap_t* handle, uint32_t event_id) {
-#if !defined(HAS_CAPTURE)
+#if !defined(HAS_CAPTURE) || defined(CYGWING_AGENT)
 	snprintf(handle->m_lasterr, SCAP_LASTERR_SIZE, "eventmask not supported on %s", PLATFORM_NAME);
 	return SCAP_FAILURE;
 #else
@@ -1346,7 +1404,7 @@ int32_t scap_enable_dynamic_snaplen(scap_t* handle)
 		return SCAP_FAILURE;
 	}
 
-#if !defined(HAS_CAPTURE)
+#if !defined(HAS_CAPTURE) || defined(CYGWING_AGENT)
 	snprintf(handle->m_lasterr, SCAP_LASTERR_SIZE, "live capture not supported on %s", PLATFORM_NAME);
 	return SCAP_FAILURE;
 #else
@@ -1376,7 +1434,7 @@ int32_t scap_disable_dynamic_snaplen(scap_t* handle)
 		return SCAP_FAILURE;
 	}
 
-#if !defined(HAS_CAPTURE)
+#if !defined(HAS_CAPTURE) || defined(CYGWING_AGENT)
 	snprintf(handle->m_lasterr, SCAP_LASTERR_SIZE, "live capture not supported on %s", PLATFORM_NAME);
 	return SCAP_FAILURE;
 #else
@@ -1398,12 +1456,15 @@ int32_t scap_disable_dynamic_snaplen(scap_t* handle)
 const char* scap_get_host_root()
 {
 	char* p = getenv("SYSDIG_HOST_ROOT");
-	if(!p)
-	{
-		p = "";
+	static char env_str[SCAP_MAX_PATH_SIZE + 1];
+	static bool inited = false;
+	if (! inited) {
+		strncpy(env_str, p ? p : "", SCAP_MAX_PATH_SIZE);
+		env_str[SCAP_MAX_PATH_SIZE] = '\0';
+		inited = true;
 	}
 
-	return p;
+	return env_str;
 }
 
 bool alloc_proclist_info(scap_t* handle, uint32_t n_entries)
@@ -1448,7 +1509,7 @@ struct ppm_proclist_info* scap_get_threadlist_from_driver(scap_t* handle)
 		return NULL;
 	}
 
-#if !defined(HAS_CAPTURE)
+#if !defined(HAS_CAPTURE) || defined(CYGWING_AGENT)
 	snprintf(handle->m_lasterr, SCAP_LASTERR_SIZE, "live capture not supported on %s", PLATFORM_NAME);
 	return NULL;
 #else
@@ -1506,7 +1567,7 @@ int32_t scap_enable_simpledriver_mode(scap_t* handle)
 		return SCAP_FAILURE;
 	}
 
-#if !defined(HAS_CAPTURE)
+#if !defined(HAS_CAPTURE) || defined(CYGWING_AGENT)
 	snprintf(handle->m_lasterr, SCAP_LASTERR_SIZE, "live capture not supported on %s", PLATFORM_NAME);
 	return SCAP_FAILURE;
 #else
@@ -1527,6 +1588,8 @@ int32_t scap_enable_simpledriver_mode(scap_t* handle)
 
 int32_t scap_get_n_tracepoint_hit(scap_t* handle, long* ret)
 {
+	int ioctl_ret = 0;
+
 	//
 	// Not supported on files
 	//
@@ -1536,14 +1599,22 @@ int32_t scap_get_n_tracepoint_hit(scap_t* handle, long* ret)
 		return SCAP_FAILURE;
 	}
 
-#if !defined(HAS_CAPTURE)
+#if !defined(HAS_CAPTURE) || defined(CYGWING_AGENT)
 	snprintf(handle->m_lasterr, SCAP_LASTERR_SIZE, "live capture not supported on %s", PLATFORM_NAME);
 	return SCAP_FAILURE;
 #else
 
-	if(ioctl(handle->m_devs[0].m_fd, PPM_IOCTL_GET_N_TRACEPOINT_HIT, ret))
+	ioctl_ret = ioctl(handle->m_devs[0].m_fd, PPM_IOCTL_GET_N_TRACEPOINT_HIT, ret);
+	if(ioctl_ret != 0)
 	{
-		snprintf(handle->m_lasterr,	SCAP_LASTERR_SIZE, "scap_get_n_tracepoint_hit failed");
+		if (errno == ENOTTY)
+		{
+			snprintf(handle->m_lasterr, SCAP_LASTERR_SIZE, "scap_get_n_tracepoint_hit failed, ioctl not supported");
+		}
+		else
+		{
+			snprintf(handle->m_lasterr, SCAP_LASTERR_SIZE, "scap_get_n_tracepoint_hit failed (%s)", strerror(errno));
+		}
 		ASSERT(false);
 		return SCAP_FAILURE;
 	}
@@ -1551,3 +1622,10 @@ int32_t scap_get_n_tracepoint_hit(scap_t* handle, long* ret)
 	return SCAP_SUCCESS;
 #endif
 }
+
+#ifdef CYGWING_AGENT
+wh_t* scap_get_wmi_handle(scap_t* handle)
+{
+	return handle->m_whh;
+}
+#endif
