@@ -70,6 +70,8 @@ typedef struct ppm_evt_hdr scap_evt;
 #define SCAP_INPUT_TOO_SMALL 5
 #define SCAP_EOF 6
 #define SCAP_UNEXPECTED_BLOCK 7
+#define SCAP_VERSION_MISMATCH 8
+#define SCAP_NOT_SUPPORTED 9
 
 //
 // Last error string size for scap_open_live()
@@ -77,7 +79,7 @@ typedef struct ppm_evt_hdr scap_evt;
 #define SCAP_LASTERR_SIZE 256
 
 /*!
-  \brief Statisitcs about an in progress capture
+  \brief Statistics about an in progress capture
 */
 typedef struct scap_stats
 {
@@ -204,6 +206,7 @@ typedef struct scap_threadinfo
 	uint64_t pid; ///< The id of the process containing this thread. In single thread processes, this is equal to tid.
 	uint64_t ptid; ///< The id of the thread that created this thread.
 	uint64_t sid; ///< The session id of the process containing this thread.
+	uint64_t vpgid; ///< The process group of this thread, as seen from its current pid namespace
 	char comm[SCAP_MAX_PATH_SIZE+1]; ///< Command name (e.g. "top")
 	char exe[SCAP_MAX_PATH_SIZE+1]; ///< argv[0] (e.g. "sshd: user@pts/4")
 	char exepath[SCAP_MAX_PATH_SIZE+1]; ///< full executable path
@@ -235,10 +238,10 @@ typedef struct scap_threadinfo
 }scap_threadinfo;
 
 typedef void (*proc_entry_callback)(void* context,
+									scap_t* handle,
 									int64_t tid,
 									scap_threadinfo* tinfo,
-									scap_fdinfo* fdinfo,
-									scap_t* newhandle);
+									scap_fdinfo* fdinfo);
 
 /*!
   \brief Arguments for scap_open
@@ -282,10 +285,10 @@ typedef struct _scap_machine_info
 	uint64_t memory_size_bytes; ///< Physical memory size
 	uint64_t max_pid; ///< Highest PID number on this machine
 	char hostname[128]; ///< The machine hostname
-	uint64_t reserved1; ///< reserved for fututre use
-	uint64_t reserved2; ///< reserved for fututre use
-	uint64_t reserved3; ///< reserved for fututre use
-	uint64_t reserved4; ///< reserved for fututre use
+	uint64_t reserved1; ///< reserved for future use
+	uint64_t reserved2; ///< reserved for future use
+	uint64_t reserved3; ///< reserved for future use
+	uint64_t reserved4; ///< reserved for future use
 }scap_machine_info;
 
 
@@ -318,7 +321,7 @@ typedef struct scap_ifinfo_ipv4
 }scap_ifinfo_ipv4;
 
 /*!
-  \brief For backword compatibility only
+  \brief For backward compatibility only
 */
 typedef struct scap_ifinfo_ipv4_nolinkspeed
 {
@@ -490,10 +493,12 @@ struct ppm_syscall_desc {
 
   \param error Pointer to a buffer that will contain the error string in case the
     function fails. The buffer must have size SCAP_LASTERR_SIZE.
+  \param rc Integer pointer that will contain the scap return code in case the
+    function fails.
 
   \return The capture instance handle in case of success. NULL in case of failure.
 */
-scap_t* scap_open_live(char *error);
+scap_t* scap_open_live(char *error, int32_t *rc);
 
 /*!
   \brief Start an event capture from file.
@@ -501,10 +506,12 @@ scap_t* scap_open_live(char *error);
   \param fname The name of the file to open.
   \param error Pointer to a buffer that will contain the error string in case the
     function fails. The buffer must have size SCAP_LASTERR_SIZE.
+  \param rc Integer pointer that will contain the scap return code in case the
+    function fails.
 
   \return The capture instance handle in case of success. NULL in case of failure.
 */
-scap_t* scap_open_offline(const char* fname, char *error);
+scap_t* scap_open_offline(const char* fname, char *error, int32_t *rc);
 
 /*!
   \brief Start an event capture from an already opened file descriptor.
@@ -512,10 +519,12 @@ scap_t* scap_open_offline(const char* fname, char *error);
   \param fd The fd to use.
   \param error Pointer to a buffer that will contain the error string in case the
     function fails. The buffer must have size SCAP_LASTERR_SIZE.
+  \param rc Integer pointer that will contain the scap return code in case the
+    function fails.
 
   \return The capture instance handle in case of success. NULL in case of failure.
 */
-scap_t* scap_open_offline_fd(int fd, char *error);
+scap_t* scap_open_offline_fd(int fd, char *error, int32_t *rc);
 
 /*!
   \brief Advanced function to start a capture.
@@ -523,10 +532,12 @@ scap_t* scap_open_offline_fd(int fd, char *error);
   \param args a \ref scap_open_args structure containing the open paraneters.
   \param error Pointer to a buffer that will contain the error string in case the
     function fails. The buffer must have size SCAP_LASTERR_SIZE.
+  \param rc Integer pointer that will contain the scap return code in case the
+    function fails.
 
   \return The capture instance handle in case of success. NULL in case of failure.
 */
-scap_t* scap_open(scap_open_args args, char *error);
+scap_t* scap_open(scap_open_args args, char *error, int32_t *rc);
 
 /*!
   \brief Close a capture handle.
@@ -561,7 +572,7 @@ char* scap_getlasterr(scap_t* handle);
   \param pcpuid User-provided event pointer that will be initialized with the ID if the CPU
     where the event was captured.
 
-  \return SCAP_SUCCESS if the call is succesful and pevent and pcpuid contain valid data.
+  \return SCAP_SUCCESS if the call is successful and pevent and pcpuid contain valid data.
    SCAP_TIMEOUT in case the read timeout expired and no event is available.
    SCAP_EOF when the end of an offline capture is reached.
    On Failure, SCAP_FAILURE is returned and scap_getlasterr() can be used to obtain the cause of the error.
@@ -630,17 +641,17 @@ uint32_t scap_event_get_dump_flags(scap_t* handle);
 int64_t scap_get_readfile_offset(scap_t* handle);
 
 /*!
-  \brief Open a tracefile for writing
+  \brief Open a trace file for writing
 
   \param handle Handle to the capture instance.
-  \param fname The name of the tracefile.
+  \param fname The name of the trace file.
 
   \return Dump handle that can be used to identify this specific dump instance.
 */
 scap_dumper_t* scap_dump_open(scap_t *handle, const char *fname, compression_mode compress);
 
 /*!
-  \brief Open a tracefile for writing, using the provided fd.
+  \brief Open a trace file for writing, using the provided fd.
 
   \param handle Handle to the capture instance.
   \param fd A file descriptor to which the dumper will write
@@ -650,14 +661,14 @@ scap_dumper_t* scap_dump_open(scap_t *handle, const char *fname, compression_mod
 scap_dumper_t* scap_dump_open_fd(scap_t *handle, int fd, compression_mode compress, bool skip_proc_scan);
 
 /*!
-  \brief Close a tracefile.
+  \brief Close a trace file.
 
   \param d The dump handle, returned by \ref scap_dump_open
 */
 void scap_dump_close(scap_dumper_t *d);
 
 /*!
-  \brief Return the current size of a tracefile.
+  \brief Return the current size of a trace file.
 
   \param d The dump handle, returned by \ref scap_dump_open
   \return The current size of the dump file pointed by d.
@@ -665,7 +676,7 @@ void scap_dump_close(scap_dumper_t *d);
 int64_t scap_dump_get_offset(scap_dumper_t *d);
 
 /*!
-  \brief Return the position for the next write to a tracefile.
+  \brief Return the position for the next write to a trace file.
          This uses gztell, while scap_dump_get_offset uses gzoffset.
 
   \param d The dump handle, returned by \ref scap_dump_open
@@ -687,7 +698,7 @@ void scap_dump_flush(scap_dumper_t *d);
   \param cpuid The cpu from which the event was captured. Returned by \ref scap_next.
   \param bytes The number of bytes to write
 
-  \return SCAP_SUCCESS if the call is succesful.
+  \return SCAP_SUCCESS if the call is successful.
    On Failure, SCAP_FAILURE is returned and scap_getlasterr() can be used to obtain
    the cause of the error.
 */
@@ -702,7 +713,7 @@ int32_t scap_number_of_bytes_to_write(scap_evt *e, uint16_t cpuid, int32_t* byte
   \param cpuid The cpu from which the event was captured. Returned by \ref scap_next.
   \param flags The event flags. 0 means no flags.
 
-  \return SCAP_SUCCESS if the call is succesful.
+  \return SCAP_SUCCESS if the call is successful.
    On Failure, SCAP_FAILURE is returned and scap_getlasterr() can be used to obtain
    the cause of the error.
 */
@@ -743,7 +754,7 @@ scap_threadinfo* scap_get_proc_table(scap_t* handle);
   \param stats Pointer to a \ref scap_stats structure that will be filled with the
   statistics.
 
-  \return SCAP_SECCESS if the call is succesful.
+  \return SCAP_SECCESS if the call is successful.
    On Failure, SCAP_FAILURE is returned and scap_getlasterr() can be used to obtain
    the cause of the error.
 */
@@ -754,7 +765,7 @@ int32_t scap_get_stats(scap_t* handle, OUT scap_stats* stats);
 
   \param handle Handle to the capture that will be stopped.
 
-  \return SCAP_SUCCESS if the call is succesful.
+  \return SCAP_SUCCESS if the call is successful.
    On Failure, SCAP_FAILURE is returned and scap_getlasterr() can be used to obtain
    the cause of the error.
 */
@@ -765,7 +776,7 @@ int32_t scap_stop_capture(scap_t* handle);
 
   \param handle Handle to the capture that will be started.
 
-  \return SCAP_SUCCESS if the call is succesful.
+  \return SCAP_SUCCESS if the call is successful.
    On Failure, SCAP_FAILURE is returned and scap_getlasterr() can be used to obtain
    the cause of the error.
 */
@@ -945,6 +956,10 @@ int32_t scap_write_proclist_trailer(scap_t *handle, scap_dumper_t *d, uint32_t t
 int32_t scap_write_proclist_entry(scap_t *handle, scap_dumper_t *d, struct scap_threadinfo *tinfo);
 int32_t scap_enable_simpledriver_mode(scap_t* handle);
 int32_t scap_get_n_tracepoint_hit(scap_t* handle, long* ret);
+#ifdef CYGWING_AGENT
+typedef struct wh_t wh_t;
+wh_t* scap_get_wmi_handle(scap_t* handle);
+#endif
 
 #ifdef __cplusplus
 }
