@@ -35,7 +35,7 @@ typedef enum filtercheck_field_flags
 	EPF_FILTER_ONLY       = 1 << 0, ///< this field can only be used as a filter.
 	EPF_PRINT_ONLY        = 1 << 1, ///< this field can only be printed.
 	EPF_REQUIRES_ARGUMENT = 1 << 2, ///< this field includes an argument, under the form 'property.argument'.
-	EPF_TABLE_ONLY        = 1 << 3, ///< this field is desgned to be used in a table and won't appear in the list created by sysdig's '-l'.
+	EPF_TABLE_ONLY        = 1 << 3, ///< this field is designed to be used in a table and won't appear in the list created by sysdig's '-l'.
 }filtercheck_field_flags;
 
 /*!
@@ -73,7 +73,7 @@ class SINSP_PUBLIC sinsp_evt_param
 {
 public:
 	char* m_val;	///< Pointer to the event parameter data.
-	uint16_t m_len; ///< Lenght os the parameter pointed by m_val.
+	uint16_t m_len; ///< Length os the parameter pointed by m_val.
 private:
 	inline void init(char* valptr, uint16_t len)
 	{
@@ -238,6 +238,16 @@ public:
 		return m_fdinfo;
 	}
 
+	inline bool fdinfo_name_changed()
+	{
+		return m_fdinfo_name_changed;
+	}
+
+	inline void set_fdinfo_name_changed(bool changed)
+	{
+		m_fdinfo_name_changed = changed;
+	}
+
 	/*!
 	  \brief Return the number of the FD associated with this event.
 
@@ -333,6 +343,7 @@ private:
 		m_info = &(m_event_info_table[m_pevt->type]);
 		m_tinfo = NULL;
 		m_fdinfo = NULL;
+		m_fdinfo_name_changed = false;
 		m_iosize = 0;
 		m_poriginal_evt = NULL;
 	}
@@ -343,6 +354,7 @@ private:
 		m_info = &(m_event_info_table[m_pevt->type]);
 		m_tinfo = NULL;
 		m_fdinfo = NULL;
+		m_fdinfo_name_changed = false;
 		m_iosize = 0;
 		m_cpuid = cpuid;
 		m_evtnum = 0;
@@ -396,6 +408,11 @@ VISIBILITY_PRIVATE
 
 	sinsp_threadinfo* m_tinfo;
 	sinsp_fdinfo_t* m_fdinfo;
+
+	// If true, then the associated fdinfo changed names as a part
+	// of parsing this event.
+	bool m_fdinfo_name_changed;
+
 	uint32_t m_iosize;
 	int32_t m_errorcode;
 	int32_t m_rawbuf_str_len;
