@@ -111,6 +111,7 @@ public:
 		m_openflags = other.m_openflags;	
 		m_sockinfo = other.m_sockinfo;
 		m_name = other.m_name;
+		m_oldname = other.m_oldname;
 		m_flags = other.m_flags;
 		m_ino = other.m_ino;
 		
@@ -285,6 +286,16 @@ public:
 		return (m_flags & (FLAGS_ROLE_CLIENT | FLAGS_ROLE_SERVER)) == 0;
 	}
 
+	inline bool is_socket_connected()
+	{
+		return (m_flags & FLAGS_SOCKET_CONNECTED) == FLAGS_SOCKET_CONNECTED;
+	}
+
+	inline bool is_cloned()
+	{
+		return (m_flags & FLAGS_IS_CLONED) == FLAGS_IS_CLONED;
+	}
+
 	scap_fd_type m_type; ///< The fd type, e.g. file, directory, IPv4 socket...
 	uint32_t m_openflags; ///< If this FD is a file, the flags that were used when opening it. See the PPM_O_* definitions in driver/ppm_events_public.h.
 	
@@ -295,6 +306,7 @@ public:
 	sinsp_sockinfo m_sockinfo;
 
 	string m_name; ///< Human readable rendering of this FD. For files, this is the full file name. For sockets, this is the tuple. And so on.
+	string m_oldname; // The name of this fd at the beginning of event parsing. Used to detect name changes that result from parsing an event.
 
 	inline bool has_decoder_callbacks()
 	{
@@ -327,6 +339,8 @@ private:
 		FLAGS_IN_BASELINE_R = (1 << 10),
 		FLAGS_IN_BASELINE_RW = (1 << 11),
 		FLAGS_IN_BASELINE_OTHER = (1 << 12),
+		FLAGS_SOCKET_CONNECTED = (1 << 13),
+		FLAGS_IS_CLONED = (1 << 14),
 	};
 
 	void add_filename(const char* fullpath);
@@ -408,6 +422,16 @@ private:
 		return (m_flags & FLAGS_IN_BASELINE_OTHER) == FLAGS_IN_BASELINE_OTHER; 
 	}
 
+	inline void set_socket_connected()
+	{
+		m_flags |= FLAGS_SOCKET_CONNECTED;
+	}
+
+	inline void set_is_cloned()
+	{
+		m_flags |= FLAGS_IS_CLONED;
+	}
+
 	T* m_usrstate;
 	uint32_t m_flags;
 	uint64_t m_ino;
