@@ -1,6 +1,7 @@
 //
 // k8s_api_handler.cpp
 //
+#ifndef CYGWING_AGENT
 
 #ifdef HAS_CAPTURE
 
@@ -102,5 +103,6 @@ bool k8s_api_handler::has(const std::string& version) const
 	return false;
 }
 
- #endif // HAS_CAPTURE
+#endif // HAS_CAPTURE
+#endif // CYGWING_AGENT
 
