@@ -136,6 +136,6 @@ public:
 	virtual void on_execve(sinsp_evt* evt) = 0;
 	virtual void on_clone(sinsp_evt* evt, sinsp_threadinfo* newtinfo) = 0;
 	virtual void on_bind(sinsp_evt* evt) = 0;
-	virtual void on_new_container(const sinsp_container_info& container_info) = 0;
+	virtual void on_new_container(const sinsp_container_info& container_info, sinsp_threadinfo *tinfo) = 0;
 	virtual void on_remove_container(const sinsp_container_info& container_info) = 0;
 };
