@@ -59,6 +59,7 @@ void sinsp_threadinfo::init()
 {
 	m_pid = (uint64_t) - 1LL;
 	m_sid = (uint64_t) - 1LL;
+	m_vpgid = (uint64_t) - 1LL;
 	set_lastevent_data_validity(false);
 	m_lastevent_type = -1;
 	m_lastevent_ts = 0;
@@ -222,6 +223,10 @@ void sinsp_threadinfo::add_fd_from_scap(scap_fdinfo *fdi, OUT sinsp_fdinfo_t *re
 		newfdi->m_sockinfo.m_ipv4info.m_fields.m_sport = fdi->info.ipv4info.sport;
 		newfdi->m_sockinfo.m_ipv4info.m_fields.m_dport = fdi->info.ipv4info.dport;
 		newfdi->m_sockinfo.m_ipv4info.m_fields.m_l4proto = fdi->info.ipv4info.l4proto;
+		if(fdi->info.ipv4info.l4proto == SCAP_L4_TCP)
+		{
+			newfdi->m_flags |= sinsp_fdinfo_t::FLAGS_SOCKET_CONNECTED;
+		}
 		if(m_inspector->m_network_interfaces)
 		{
 			m_inspector->m_network_interfaces->update_fd(newfdi);
@@ -255,6 +260,10 @@ void sinsp_threadinfo::add_fd_from_scap(scap_fdinfo *fdi, OUT sinsp_fdinfo_t *re
 			newfdi->m_sockinfo.m_ipv4info.m_fields.m_sport = fdi->info.ipv6info.sport;
 			newfdi->m_sockinfo.m_ipv4info.m_fields.m_dport = fdi->info.ipv6info.dport;
 			newfdi->m_sockinfo.m_ipv4info.m_fields.m_l4proto = fdi->info.ipv6info.l4proto;
+			if(fdi->info.ipv6info.l4proto == SCAP_L4_TCP)
+			{
+				newfdi->m_flags |= sinsp_fdinfo_t::FLAGS_SOCKET_CONNECTED;
+			}
 			if(m_inspector->m_network_interfaces)
 			{
 				m_inspector->m_network_interfaces->update_fd(newfdi);
@@ -268,6 +277,10 @@ void sinsp_threadinfo::add_fd_from_scap(scap_fdinfo *fdi, OUT sinsp_fdinfo_t *re
 			newfdi->m_sockinfo.m_ipv6info.m_fields.m_sport = fdi->info.ipv6info.sport;
 			newfdi->m_sockinfo.m_ipv6info.m_fields.m_dport = fdi->info.ipv6info.dport;
 			newfdi->m_sockinfo.m_ipv6info.m_fields.m_l4proto = fdi->info.ipv6info.l4proto;
+			if(fdi->info.ipv6info.l4proto == SCAP_L4_TCP)
+			{
+				newfdi->m_flags |= sinsp_fdinfo_t::FLAGS_SOCKET_CONNECTED;
+			}
 			newfdi->m_name = ipv6tuple_to_string(&newfdi->m_sockinfo.m_ipv6info, m_inspector->m_hostname_and_port_resolution_enabled);
 		}
 		break;
@@ -361,6 +374,7 @@ void sinsp_threadinfo::init(scap_threadinfo* pi)
 	m_pid = pi->pid;
 	m_ptid = pi->ptid;
 	m_sid = pi->sid;
+	m_vpgid = pi->vpgid;
 
 	m_comm = pi->comm;
 	m_exe = pi->exe;
@@ -523,26 +537,29 @@ const vector<string>& sinsp_threadinfo::get_env()
 		else
 		{
 			// it should never happen but provide a safe fallback just in case
+			// except during sinsp::scap_open() (see sinsp::get_thread()).
 			ASSERT(false);
 			return m_env;
 		}
 	}
 }
 
+// Return value string for the exact environment variable name given
 string sinsp_threadinfo::get_env(const string& name)
 {
+	size_t nlen = name.length();
 	for(const auto& env_var : get_env())
 	{
-		if((env_var.length() > name.length()) && (env_var.substr(0, name.length()) == name))
+		if((env_var.length() > (nlen + 1)) && (env_var[nlen] == '=') &&
+			!env_var.compare(0, nlen, name))
 		{
-			std::string::size_type pos = env_var.find('=');
-			if(pos != std::string::npos && env_var.size() > pos + 1)
-			{
-				string val = env_var.substr(pos + 1);
-				std::string::size_type first = val.find_first_not_of(' ');
-				std::string::size_type last = val.find_last_not_of(' ');
-				return val.substr(first, last - first + 1);
-			}
+			// Stripping spaces, not sure if we really should or need to
+			size_t first = env_var.find_first_not_of(' ', nlen + 1);
+			if (first == string::npos)
+				return "";
+			size_t last = env_var.find_last_not_of(' ');
+
+			return env_var.substr(first, last - first + 1);
 		}
 	}
 
@@ -1264,7 +1281,7 @@ void sinsp_thread_manager::remove_thread(threadinfo_map_iterator_t it, bool forc
 
 		//
 		// If the thread has a nonzero refcount, it means that we are forcing the removal
-		// of a main process or program that some childs refer to.
+		// of a main process or program that some child refer to.
 		// We need to recalculate the child relationships, or the table will become
 		// corrupted.
 		//
@@ -1368,6 +1385,7 @@ void sinsp_thread_manager::thread_to_scap(sinsp_threadinfo& tinfo, 	scap_threadi
 	sctinfo->pid = tinfo.m_pid;
 	sctinfo->ptid = tinfo.m_ptid;
 	sctinfo->sid = tinfo.m_sid;
+	sctinfo->vpgid = tinfo.m_vpgid;
 
 	strncpy(sctinfo->comm, tinfo.m_comm.c_str(), SCAP_MAX_PATH_SIZE);
 	strncpy(sctinfo->exe, tinfo.m_exe.c_str(), SCAP_MAX_PATH_SIZE);
@@ -1422,6 +1440,7 @@ void sinsp_thread_manager::dump_threads_to_file(scap_dumper_t* dumper)
 			sizeof(uint64_t) +	// pid
 			sizeof(uint64_t) +	// ptid
 			sizeof(uint64_t) +	// sid
+			sizeof(uint64_t) +  // pgid
 			2 + MIN(tinfo.m_comm.size(), SCAP_MAX_PATH_SIZE) +
 			2 + MIN(tinfo.m_exe.size(), SCAP_MAX_PATH_SIZE) +
 			2 + MIN(tinfo.m_exepath.size(), SCAP_MAX_PATH_SIZE) +
