@@ -9,28 +9,35 @@
 #include <netdb.h>
 #endif
 
-void sinsp_filter_value_parser::string_to_rawval(const char* str, uint32_t len, uint8_t *storage, string::size_type max_len, ppm_param_type ptype)
+size_t sinsp_filter_value_parser::string_to_rawval(const char* str, uint32_t len, uint8_t *storage, string::size_type max_len, ppm_param_type ptype)
 {
+	size_t parsed_len;
+
 	switch(ptype)
 	{
 		case PT_INT8:
 			*(int8_t*)storage = sinsp_numparser::parsed8(str);
+			parsed_len = sizeof(int8_t);
 			break;
 		case PT_INT16:
 			*(int16_t*)storage = sinsp_numparser::parsed16(str);
+			parsed_len = sizeof(int16_t);
 			break;
 		case PT_INT32:
 			*(int32_t*)storage = sinsp_numparser::parsed32(str);
+			parsed_len = sizeof(int32_t);
 			break;
 		case PT_INT64:
 		case PT_FD:
 		case PT_ERRNO:
 			*(int64_t*)storage = sinsp_numparser::parsed64(str);
+			parsed_len = sizeof(int64_t);
 			break;
 		case PT_L4PROTO: // This can be resolved in the future
 		case PT_FLAGS8:
 		case PT_UINT8:
 			*(uint8_t*)storage = sinsp_numparser::parseu8(str);
+			parsed_len = sizeof(int8_t);
 			break;
 		case PT_PORT:
 		{
@@ -62,22 +69,27 @@ void sinsp_filter_value_parser::string_to_rawval(const char* str, uint32_t len,
 				}
 			}
 
+			parsed_len = sizeof(int16_t);
 			break;
 		}
 		case PT_FLAGS16:
 		case PT_UINT16:
 			*(uint16_t*)storage = sinsp_numparser::parseu16(str);
+			parsed_len = sizeof(uint16_t);
 			break;
 		case PT_FLAGS32:
 		case PT_UINT32:
 			*(uint32_t*)storage = sinsp_numparser::parseu32(str);
+			parsed_len = sizeof(uint32_t);
 			break;
 		case PT_UINT64:
 			*(uint64_t*)storage = sinsp_numparser::parseu64(str);
+			parsed_len = sizeof(uint64_t);
 			break;
 		case PT_RELTIME:
 		case PT_ABSTIME:
 			*(uint64_t*)storage = sinsp_numparser::parseu64(str);
+			parsed_len = sizeof(uint64_t);
 			break;
 		case PT_CHARBUF:
 		case PT_SOCKADDR:
@@ -91,9 +103,11 @@ void sinsp_filter_value_parser::string_to_rawval(const char* str, uint32_t len,
 
 				memcpy(storage, str, len);
 				*(uint8_t*)(&storage[len]) = 0;
+				parsed_len = len;
 			}
 			break;
 		case PT_BOOL:
+			parsed_len = sizeof(uint32_t);
 			if(string(str) == "true")
 			{
 				*(uint32_t*)storage = 1;
@@ -113,6 +127,7 @@ void sinsp_filter_value_parser::string_to_rawval(const char* str, uint32_t len,
 			{
 				throw sinsp_exception("unrecognized IP address " + string(str));
 			}
+			parsed_len = sizeof(struct in_addr);
 			break;
 		case PT_IPV4NET:
 		{
@@ -150,11 +165,14 @@ void sinsp_filter_value_parser::string_to_rawval(const char* str, uint32_t len,
 
 			net->m_netmask = htonl(net->m_netmask);
 
+			parsed_len = sizeof(ipv4net);
 			break;
 		}
 		default:
 			ASSERT(false);
 			throw sinsp_exception("wrong parameter type " + to_string((long long) ptype));
 	}
+
+	return parsed_len;
 }
 
