@@ -25,5 +25,5 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 class sinsp_filter_value_parser
 {
  public:
-	static void string_to_rawval(const char* str, uint32_t len, uint8_t *storage, string::size_type max_len, ppm_param_type ptype);
+	static size_t string_to_rawval(const char* str, uint32_t len, uint8_t *storage, string::size_type max_len, ppm_param_type ptype);
 };
