@@ -262,7 +262,6 @@ captureinfo do_inspect(sinsp* inspector,
 			{
 				ui->set_truncated_input(true);
 				res = SCAP_EOF;
-				continue;
 			}
 		}
 
@@ -672,7 +671,7 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 		}
 
 		//
-		// Set the initial disply view
+		// Set the initial display view
 		//
 		view_manager.set_selected_view(display_view);
 
@@ -899,6 +898,11 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 	catch(sinsp_capture_interrupt_exception&)
 	{
 	}
+	catch(sinsp_exception& e)
+	{
+		errorstr = e.what();
+		res.m_res = e.scap_rc();
+	}
 	catch(std::exception& e)
 	{
 		errorstr = e.what();
